<?php

//	BlockHUB System
//	https://demo.blockhubsys.de
//	info@blockhubsys.de

session_start();

$dataDir = "data";
$jsonFile = $dataDir . "/cc.json";
$currentText = '';

if (file_exists($jsonFile)) {
    $jsonData = file_get_contents($jsonFile);
    $data = json_decode($jsonData, true);

    if ($data !== null && isset($data['text'])) {
        $currentText = $data['text'];
    } else {
        error_log("Error decoding JSON data from file: " . $jsonFile);
        $currentText = 'Standard Cookie Text';
    }
} else {
    error_log("The file " . $jsonFile . " does not exist.");
    $currentText = 'Standard Cookie Text';
}

if (isset($_POST['acceptCookies'])) {
    $_SESSION['cookiesAccepted'] = true;
    header("Location: " . $_SERVER['PHP_SELF']);
    exit();
}
$cookiesAccepted = isset($_SESSION['cookiesAccepted']) ? $_SESSION['cookiesAccepted'] : false;

$contentFile = 'content.json';

$data = [];

if (file_exists($contentFile)) {
    $content = json_decode(file_get_contents($contentFile), true);

    if (json_last_error() !== JSON_ERROR_NONE) {
        echo "Error decoding JSON file: " . json_last_error_msg();
        exit;
    }

    $data = $content;
} else {
    echo 'File not found: ' . $contentFile;
    exit;
}

$startpage = isset($data['startpage']) ? $data['startpage'] : null;

$uploadDir = 'uploads/';
$logoFile = $uploadDir . 'logo';
$bannerFile = $uploadDir . 'banner';
$extensions = ['.jpg', '.jpeg', '.png', '.gif', '.bmp'];
$logoPath = '';
$bannerPath = '';

foreach ($extensions as $ext) {
    if (file_exists($logoFile . $ext)) {
        $logoPath = $logoFile . $ext;
        break;
    }
}


foreach ($extensions as $ext) {
    if (file_exists($bannerFile . $ext)) {
        $bannerPath = $bannerFile . $ext;
        break;
    }
}

$faviconPath = 'uploads/favicon';
$faviconUrl = '';
foreach ($extensions as $ext) {
    if (file_exists($faviconPath . $ext)) {
        $faviconUrl = $faviconPath . $ext;
        break;
    }
}

$title = isset($content['title']) ? $content['title'] : '';

$dataDir = "data";
$jsonFile = $dataDir . "/cc.json";
$currentText = '';

if (file_exists($jsonFile)) {
    $cookieData = json_decode(file_get_contents($jsonFile), true);
    $currentText = isset($cookieData['cookiecompilation']) ? $cookieData['cookiecompilation'] : '';
}
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <?php if ($faviconUrl): ?>
        <link rel="icon" href="<?php echo $faviconUrl; ?>" type="image/x-icon">
    <?php endif; ?>

    <title><?php echo htmlspecialchars($title); ?></title>
    <link rel="stylesheet" href="style.css">
</head>
<body>
<header>
    <?php if ($bannerPath): ?>
        <div class="banner"><img src="<?php echo htmlspecialchars($bannerPath); ?>" alt="Banner"></div>
    <?php endif; ?>

    <input type="checkbox" id="menu_checkbox">
    <label for="menu_checkbox">
        <div></div>
        <div></div>
        <div></div>
    </label>

    <ul>
        <?php if ($logoPath): ?>
            <div class="logo2"><img src="<?php echo htmlspecialchars($logoPath); ?>" alt="Logo" class="logo"></div>
        <?php endif; ?>

        <?php
        if (isset($data['pages']) && is_array($data['pages'])) {

            foreach ($data['pages'] as $page) {
                $isActive = (isset($_GET['title']) && $_GET['title'] === $page['title'])
                            || (!isset($_GET['title']) && $page['title'] === $startpage) ? 'active' : '';

                echo '<li><a href="index.php?title=' . urlencode($page['title']) . '" class="' . $isActive . '">' . htmlspecialchars($page['title']) . '</a></li>';
            }
        } else {
            echo '<p>No Site found</p>';
        }
        ?>
    </ul>
</header>

<main>
    <?php
    if (!isset($_GET['title'])) {
        $title = $startpage;
    } else {
        $title = $_GET['title'];
    }

    $pageFound = false;
    foreach ($data['pages'] as $page) {
        if ($page['title'] === $title) {
            $pageFound = true;

            echo '<div class="title"><h1>' . htmlspecialchars($page['title']) . '</h1></div>';

            function bbcode_to_html($bbcode) {
                $bbcode = preg_replace('/\[b\](.*?)\[\/b\]/s', '<strong>$1</strong>', $bbcode);
                $bbcode = preg_replace('/\[i\](.*?)\[\/i\]/s', '<em>$1</em>', $bbcode);
                $bbcode = preg_replace('/\[u\](.*?)\[\/u\]/s', '<u>$1</u>', $bbcode);
                $bbcode = preg_replace('/\[h3\](.*?)\[\/h3\]/s', '<span class="title1">$1</span>', $bbcode);
                $bbcode = preg_replace('/\[h4\](.*?)\[\/h4\]/s', '<span class="title2">$1</span>', $bbcode);
                $bbcode = preg_replace('/\[b\](.*?)\[\/b\]/', '<strong>$1</strong>', $bbcode);
                $bbcode = preg_replace('/\[i\](.*?)\[\/i\]/', '<em>$1</em>', $bbcode);
                $bbcode = preg_replace('/\[u\](.*?)\[\/u\]/', '<u>$1</u>', $bbcode);
                $bbcode = preg_replace('/\[h3\](.*?)\[\/h3\]/s', '<span class="title1">$1</span>', $bbcode);
                $bbcode = preg_replace('/\[h4\](.*?)\[\/h4\]/s', '<span class="title2">$1</span>', $bbcode);
                $bbcode = preg_replace('/\[url=([^\]]+)\](.*?)\[\/url\]/', '<a href="$1">$2</a>', $bbcode);
                $bbcode = preg_replace('/\[li\](.*?)\[\/li\]/', '<li>$1</li>', $bbcode);
              return $bbcode;
            }

            $formattedContent = bbcode_to_html($page['content']);
            $filteredContent = preg_replace('/contenteditable="true"/i', '', $formattedContent);

            echo '<div class="content-display">' . $filteredContent . '</div>';

            break;
        }
    }

    if (!$pageFound) {
        echo '<p>Seite nicht gefunden.</p>';
    }
    ?>
</main>

<footer>
 <center>
    <?php if (!$cookiesAccepted): ?>
        <div id="cookiePopup"><center>
            <div style="width:100%; text-align:left;"><p>    <?php if (!empty($currentText)): ?>
        <?= htmlspecialchars($currentText); ?>
    <?php endif; ?>
    </p></div>
            <form method="post">
                <div style="width:100%; text-align:right;"><button type="submit" name="acceptCookies" class="accept">Accept Cookies</button></div>
            </form>
        </center></div></div>
    <?php endif; ?>
</center>
</footer>

<script>
    function showCookiePopup() {
        const popup = document.getElementById('cookiePopup');
        popup.style.display = 'block';  // Popup wird immer angezeigt
    }
    function acceptCookies() {
        document.getElementById('cookiePopup').style.display = 'none'; // Popup wird geschlossen
    }
    window.onload = showCookiePopup;
</script>


</body>
</html>